@@ -356,7 +356,7 @@ class MainWindow(QMainWindow): # Class for main application
 				if int(TIME2BEEB) != 0:
 					if timeSeconds >= 1 and timeSeconds % int(TIME2BEEB) == 0:
 						globURI = beeb 
-						player().start()
+						player().run()
 						if timeSeconds >= 600:
 							timeSeconds = 0
 
@@ -371,7 +371,7 @@ class MainWindow(QMainWindow): # Class for main application
 					seconds -= 1
 				else:
 					globURI = alert
-					player().start()
+					player().run()
 					self.timer.stop()
 					self.buttonClicked("bulbButton")
 					timeAdded = False
@@ -433,7 +433,7 @@ class MainWindow(QMainWindow): # Class for main application
 				self.timeLeft.setText("Session ready!")
 				self.startButton.setText("Clear")
 				globURI = alert
-				player().start()
+				player().run()
 				self.timer.stop()
 		else:
 			self.photoLabel.setText("%i" %photosTaken)
@@ -454,7 +454,7 @@ class MainWindow(QMainWindow): # Class for main application
 			string = "Session ready!"
 			self.startButton.setText("Clear")
 			globURI = alert
-			player().start()
+			player().run()
 						
 			self.timer.stop()
 			
@@ -1174,11 +1174,17 @@ class MiscFunctions:
 		 
 class player (QThread):
 	def run(self):
+		print "a"
 		QThread.__init__(self)
+		print "b"
 		global beebRun
+		print "c"
 		player = gst.element_factory_make("playbin","player")
+		print "d"
 		player.set_property('uri', globURI)
+		print "e"
 		player.set_state(gst.STATE_PLAYING)
+		print "done"
 				
 class digitalCamera: # This is class where commands from GUI are translated ready to be send to camera
 	def olympus(self,rawdata):
